#
# spec file for package blktests
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           blktests
Version:        0+20201022.e10add0
Release:        bp155.2.11
Summary:        Linux kernel block layer testing framework
License:        GPL-2.0-or-later
URL:            https://github.com/osandov/blktests
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
Requires:       fio
Requires:       gawk
Requires:       gcc
Requires:       make
Recommends:     blktrace
Recommends:     device-mapper
Recommends:     e2fsprogs
Recommends:     multipath-tools
Recommends:     nvme-cli
Recommends:     xfsprogs

%description
blktests is a test framework for the Linux kernel block layer and
storage stack. It is inspired by the xfstests filesystem testing
framework.

%prep
%setup -q

%build
make %{?_smp_mflags} V=1

%install
%make_install prefix="%{_prefix}/lib"

%files
%doc README.md
%license LICENSES/GPL-2.0 LICENSES/GPL-3.0
%{_prefix}/lib/blktests

%changelog
* Wed Dec  2 2020 pcervinka@suse.com
- Update to version 0+20201022.e10add0:
  * nvme/038: Test removal of un-enabled subsystem and ports
  * nvme/037: Add test which loops passthru connect and disconnect
  * nvme/036: Add test for testing reset command on nvme-passthru
  * nvme/035: Add test to verify passthru controller with a filesystem
  * nvme/034: Add test for passthru data verification
  * nvme/033: Simple test to create and connect to a passthru target
  * nvme: Add common helpers for passthru tests
  * nvme: Search for specific subsysnqn in _find_nvme_loop_dev
  * common/xfs: Create common helper to verify block device with xfs
  * common/xfs: Create common helper to check for XFS support
  * common/fio: Remove state file in common helper
  * zbd/003: Reset zones when the test device has max_active_zones limit
  * block/004: Provide max_active_zones to fio command
  * common/rc: Add _test_dev_max_active_zones() helper function
  * nvme: support rdma transport type
  * common: move module_unload to common
  * nvme: support nvme-tcp when runinng tests
  * tests/nvme: restrict tests to specific transports
  * nvme: make tests transport type agnostic
  * nvme: consolidate some nvme-cli utility functions
  * nvme: consolidate nvme requirements based on transport type
  * nvme/005: add the missing _have_program nvme
  * common/multipath-over-rdma: make block scheduler directory optional
  * zbd/002: Check write pointers only when zones have valid conditions
  * zbd/005: Enable zonemode=zbd when zone capacity is less than zone size
  * zbd/004: Check zone boundary writes using zones without zone capacity gap
  * zbd/002: Check validity of zone capacity
  * zbd/rc: Support zone capacity report by blkzone
  * Remove partition rereading tests for reverted fixes
  * tests/srp/rc: Separate login parameters with a comma
  * srp tests: Use _{init,exit}_scsi_debug() instead of duplicating these functions
  * common/multipath-over-rdma: Log mkfs output
  * srp, nvmeof-mp: Use no_path_retry instead of queue_if_no_path
  * tests/nvmeof-mp/rc: Make login failures easier to debug
  * block/012: add comment explaning second --setro
  * tests/srp/rc: Fix a shellcheck warning
  * tests: mark tests with CAN_BE_ZONED=1
  * common/cpuhotplug: fix ALL_CPUS
  * tests/srp/rc: Do not pass an empty string to dd
  * zbd/007: Add --force option to blkzone reset
  * Fix ./check: line 275: LAST_TEST_RUN["$key"]: unbound variable
  * Fix unquoted integer shellcheck errors
  * travis: update shellcheck URL
  * tests/srp/rc: Make the SRP tests pass against kernel v5.7
* Fri May  1 2020 Petr Cervinka <pcervinka@suse.com>
- Update to version 0+20200430.bff70b0:
  * Add $DESCRIPTION to the TEST_RUN
  * Fix unintentional skipping of tests
  * Add a test that triggers the blk_mq_realloc_hw_ctxs() error path
  * Introduce the function _configure_null_blk()
  * Use _{init,exit}_null_blk instead of open-coding these functions
  * Make _exit_null_blk remove all null_blk device instances
  * common/fio: do not use norandommap with verify
* Thu Apr  2 2020 Sebastian Chlad <sebastian.chlad@suse.com>
- Add blktrace to recommended as some tests require it
* Wed Mar 25 2020 pcervinka@suse.com
- Update to version 20200307.cd11d00:
  * Support skipping tests from test{,_device}()
  * Show last run for skipped tests
  * Skip tests based on SKIP_REASON, not return value
  * nbd/003: fix compiling error with gcc version 4.8.5
  * nbd/003:add mount and clear_sock test for nbd
  * nvme/018: Reword misleading error message
  * nvme/018: Ignore message generated by nvme read
  * tests/srp/015: Add a test that uses the SoftiWARP (siw) driver
  * common/multipath-over-rdma, tests/srp: Make it easy to use siw instead of rdma_rxe
  * common/multipath-over-rdma: Rename two functions
- Apply spec-cleaner
- Change version format in service file
- Add GPL-3.0 to license list
- Add README.md to doc section
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Nov 25 2018 Jan Engelhardt <jengelh@inai.de>
- Move /var/lib/blktests to /usr/lib/blktests, packages don't
  deliver variadic data.
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Fix package dependencies: nvmetcli is not needed, some packages
  can be missing (changed to Recommended:)
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- fix the %%files section: change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Correct the package category, System/Benchmarks is wrong
-> System/Benchmark
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  Move the installed files from /usr/share to /var/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  move the installed files from /usr/local to /usr/share
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- clean the .spec
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- fix the group of the package
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- Add the blktests.spec file
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
  Add new package for "blktests", the linux block layer testing framework
  from https://github.com/osandov/blktests
-
